//+------------------------------------------------------------------+
//|                                      cam_H2_H5_Historical_V4.mq4 |
//|                      Copyright  2005, MetaQuotes Software Corp. |
//|                                        http://www.metaquotes.net |
//| Modified to chart historical camarilla pivots by MrPip           |
//| 3/28/06 Fixed problem of Sunday/Monday pivots                    |
//|         and added some ideas from goodtiding5 (Kenneth Z.)       |
//+------------------------------------------------------------------+
#property copyright "Copyright  2005, MetaQuotes Software Corp."
#property link      "http://www.metaquotes.net"

#property indicator_chart_window
#property indicator_buffers 8
#property indicator_color1 Lime
#property indicator_color2 Lime
#property indicator_color3 Lime
#property indicator_color4 Lime
#property indicator_color5 Yellow
#property indicator_color6 Red
#property indicator_color7 Pink
#property indicator_color8 Pink
#property indicator_width1 1
#property indicator_width2 1
#property indicator_width3 1
#property indicator_width4 1
#property indicator_width5 1
#property indicator_width6 1
#property indicator_width7 1
#property indicator_width8 1
//---- input parameters

extern int  GMTshift=0;
extern color HColor = Lime;
extern int fontsize=8;
extern int LabelShift=1;
extern int DrawDays=5;

double H5Buffer[];
double H4Buffer[];
double H3Buffer[];
double H2Buffer[];
double PivotBuffer[];
double YDHBuffer[];
double R1Buffer[];
double R2Buffer[];

double P, H2, H3, H4, H5, DPHPL, PH, DrawDay, R1, R2;

double D1=0.091667;
double D2=0.183333;
double D3=0.2750;
double D4=0.55;

double prev_high=0;
double prev_low=0;
double prev_close=0;
double cur_day=0;
double prev_day=0;
double day_high=0;
double day_low=0;

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
  {
   IndicatorBuffers(8);
//---- indicators
   SetIndexStyle(0,DRAW_LINE, 0,1,Lime);
   SetIndexBuffer(0,H5Buffer);
   SetIndexStyle(1,DRAW_LINE, 0,1,Lime);
   SetIndexBuffer(1,H4Buffer);
   SetIndexStyle(2,DRAW_LINE, 0,1,Lime);
   SetIndexBuffer(2,H3Buffer);
   SetIndexStyle(3,DRAW_LINE, 0,1,Lime);
   SetIndexBuffer(3,H2Buffer);
   SetIndexStyle(4,DRAW_LINE, STYLE_DOT, 1, Yellow);
   SetIndexBuffer(4,PivotBuffer);
   SetIndexStyle(5,DRAW_LINE, STYLE_DOT, 1, Red);
   SetIndexBuffer(5,YDHBuffer);
   SetIndexStyle(6,DRAW_LINE, 0, 1, Pink);
   SetIndexBuffer(6,R1Buffer);
   SetIndexStyle(7,DRAW_LINE, 0, 1, Pink);
   SetIndexBuffer(7,R2Buffer);
   
   SetIndexLabel(0,"H5");
   SetIndexLabel(1,"H4");
   SetIndexLabel(2,"H3");
   SetIndexLabel(3,"H2");
   SetIndexLabel(4,"Pivot");
   SetIndexLabel(5,"YesterdayHigh");
   SetIndexLabel(6,"R1");
   SetIndexLabel(7,"R2");

   
//----
//   IndicatorShortName("Cam H Pivots");
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| Custor indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
  {
//---- TODO: add your code here
   ObjectDelete("CamPivot");
   ObjectDelete("ResH2");
   ObjectDelete("ResH3");
   ObjectDelete("ResH4");
   ObjectDelete("ResH5");  
   ObjectDelete("YesterdayHigh"); 
   ObjectDelete("ResR1"); 
   ObjectDelete("ResR2"); 
//----
   return(0);
  }

//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start()
{
if (Period()==1){DrawDay = (DrawDays*1440);}
if (Period()==5){DrawDay = (DrawDays*288);}
if (Period()==15){DrawDay = (DrawDays*96);}
if (Period()==30){DrawDay = (DrawDays*48);}
if (Period()==60){DrawDay = (DrawDays*24);}
if (Period()==240){DrawDay = (DrawDays*6);}

if (DrawDay>Bars) DrawDay=Bars;

  {
   int    counted_bars=IndicatorCounted();
   int cnt, limit;

//---- exit if period is greater than 4 hr charts
   if(Period() > 240)
   {
      //Alert("Error - Chart period is greater than 4 Hr.");
      return(-1); // then exit
   }
   if(counted_bars<0) return(-1);

//---- last counted bar will be recounted
//   if(counted_bars>0) counted_bars--;

//   limit=(Bars-counted_bars)-1;
   limit=DrawDay;

//---- Get new daily prices & calculate pivots

   for (cnt=limit;cnt >=0;cnt--)
   {
   	if (TimeDayOfWeek(Time[cnt]) == 0)
	   {
        cur_day = prev_day;
	   }
	   else
	   {
        cur_day = TimeDay(Time[cnt]- (GMTshift*3600));
	   }
	   
   	if (prev_day != cur_day)
   	{
	   	prev_close = Close[cnt+1];
		   prev_high = day_high;
		   prev_low = day_low;

	      day_high = High[cnt];
 	      day_low  = Low[cnt];
DPHPL = prev_high/MathMax( prev_low, 0.000001 );
P = (prev_high + prev_low + prev_close)/3;//Pivot
//---- To display all 8 Camarilla pivots remove comment symbols below and
// add the appropriate object functions below
//H5 = (prev_high/prev_low)*prev_close;
H5 = DPHPL*prev_close;
H4 = ((prev_high - prev_low)* D4) + prev_close;
H3 = ((prev_high - prev_low)* D3) + prev_close;
H2 = ((prev_high - prev_low) * D2) + prev_close;
////H1 = ((prev_high - prev_low) * D1) + prev_close;
PH = prev_high;
R1 = (2*P)-prev_low;
R2 = P+(prev_high - prev_low);


		   prev_day = cur_day;
	   }
      if (High[cnt]>day_high)
      {
         day_high = High[cnt];
      }
      if (Low[cnt]<day_low)
      {
         day_low = Low[cnt];
      }
      
      
      
//         day_low=Open[cnt]; day_high=Open[cnt];
      
      

//---  Draw  Pivot lines on chart
      YDHBuffer[cnt]=prev_high;
      PivotBuffer[cnt]=P;
      H5Buffer[cnt]=H5;
      H4Buffer[cnt]=H4;
      H3Buffer[cnt]=H3;
      H2Buffer[cnt]=H2;
      R1Buffer[cnt]=R1;
      R2Buffer[cnt]=R2;
   }

  if (cur_day == TimeDay(CurTime()))   DisplayLabels();
//----

}
   return(0);
  }

void DisplayLabels()
{ 

string PS=DoubleToStr(P,Digits);
string H2S=DoubleToStr(H2,Digits);
string H3S=DoubleToStr(H3,Digits);
string H4S=DoubleToStr(H4,Digits);
string H5S=DoubleToStr(H5,Digits);
string YDHS=DoubleToStr(PH,Digits);
string R1S=DoubleToStr(R1,Digits);
string R2S=DoubleToStr(R2,Digits);  

      if(ObjectFind("CamPivot") != 0)
      {
        ObjectCreate("CamPivot", OBJ_TEXT, 0, 0, 0);
        ObjectSetText("CamPivot","                      Pivot "+PS,fontsize,"Arial",Yellow);
        
      }
      else
      {
        ObjectMove("CamPivot", 0, Time[LabelShift],P);
      }
      
      if(ObjectFind("ResH2") != 0)
      {
      ObjectCreate("ResH2", OBJ_TEXT, 0, 0, 0);
      ObjectSetText("ResH2", "                   H2 "+H2S,fontsize,"Arial",HColor);
      }
      else
      {
         ObjectMove("ResH2", 0, Time[LabelShift],H2);
      }
      
      if(ObjectFind("ResH3") != 0)
      {
      ObjectCreate("ResH3", OBJ_TEXT, 0, 0, 0);
      ObjectSetText("ResH3", "                   H3 "+H3S,fontsize,"Arial",HColor);
      }
      else
      {
         ObjectMove("ResH3", 0, Time[LabelShift],H3);
      }
      
      if(ObjectFind("ResH4") != 0)
      {
      ObjectCreate("ResH4", OBJ_TEXT, 0, 0, 0);
      ObjectSetText("ResH4", "                   H4 "+H4S,fontsize,"Arial",HColor);
      }
      else
      {
         ObjectMove("ResH4", 0, Time[LabelShift],H4);
      }
      
      if(ObjectFind("ResH5") != 0)
      {
      ObjectCreate("ResH5", OBJ_TEXT, 0, 0, 0);
      ObjectSetText("ResH5", "                   H5 "+H5S,fontsize,"Arial",HColor);
      }
      else
      {
         ObjectMove("ResH5", 0, Time[LabelShift],H5);
      }
      if(ObjectFind("YesterdayHigh") != 0)
      {
      ObjectCreate("YesterdayHigh", OBJ_TEXT, 0, 0, 0);
      ObjectSetText("YesterdayHigh", "                           YD High "+YDHS,fontsize,"Arial",Red);
      }
      else
      {
         ObjectMove("YesterdayHigh", 0, Time[LabelShift],prev_high);
      }
      if(ObjectFind("ResR1") != 0)
      {
      ObjectCreate("ResR1", OBJ_TEXT, 0, 0, 0);
      ObjectSetText("ResR1", "                   R1 "+R1S,fontsize,"Arial",Pink);
      }
      else
      {
         ObjectMove("ResR1", 0, Time[LabelShift],R1);
      }
      if(ObjectFind("ResR2") != 0)
      {
      ObjectCreate("ResR2", OBJ_TEXT, 0, 0, 0);
      ObjectSetText("ResR2", "                   R2 "+R2S,fontsize,"Arial",Pink);
      }
      else
      {
         ObjectMove("ResR2", 0, Time[LabelShift],R2);
      }
    
}
//+------------------------------------------------------------------+